/**
 * Pyx4me framework
 * Copyright (C) 2006-2008 pyx4j.com.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 * @author vlads
 * @version $Id: WtkJadMojo.java 2070 2008-06-21 23:47:04Z vlads $
 */
package com.pyx4me.maven.j2me;

import org.apache.maven.plugin.MojoExecutionException;
import org.apache.maven.plugin.MojoFailureException;

import de.pleumann.antenna.WtkJad;

/**
 * 
 * <p>
 * The WtkJad task allows to create new JAD files from scratch. In particular,
 * it is able to update the MIDlet-Jar-Size keys automatically. Antenna library
 * is used for this task.
 * </p>
 * 
 * @goal jad
 * @phase package
 * @description Create JAD files
 * 
 */

public class WtkJadMojo extends AbstractJadWtkMojo {

	public void execute() throws MojoExecutionException, MojoFailureException {
		executeCreateJad(this, classifier, false);
	}

	public static void executeCreateJad(AbstractJadWtkMojo mojo, String packageClassifier, boolean isTest)
			throws MojoExecutionException, MojoFailureException {
		if (mojo.wtkHome != null) {
			executeAntenna(mojo, packageClassifier, isTest);
		} else {
			mojo.executeCreateJad(packageClassifier, isTest);
		}
	}

	private static void executeAntenna(AbstractJadWtkMojo mojo, String packageClassifier, boolean isTest)
			throws MojoExecutionException, MojoFailureException {
		WtkJad task = mojo.createWtkJadTask(packageClassifier, isTest);
		mojo.executeTask(task);
	}

}
