/**
 * Pyx4me framework
 * Copyright (C) 2006-2008 pyx4j.com.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 * @author francisdb
 * @version $Id: WtkSignMojo.java 2105 2008-07-08 15:25:35Z vlads $
 */
package com.pyx4me.maven.j2me;

import java.io.File;

import org.apache.maven.plugin.MojoExecutionException;
import org.apache.maven.plugin.MojoFailureException;

import de.pleumann.antenna.WtkSign;

/**
 * 
 * <p>
 * The WtkSign task allows to sign a jad/jar pair. In particular, it will sign
 * the jar and add the certificate to the jad. Antenna library is used for this
 * task.
 * </p>
 * 
 * @goal sign
 * @phase package
 * @description Sign JAD/JAR files
 * 
 */
public class WtkSignMojo extends WtkJadMojo {

    /**
     * The keystore file
     * 
     * @parameter expression="${j2me.keystore}"
     * @required
     */
    protected File keystore;

    /**
     * The keystore password
     * 
     * @parameter expression="${j2me.keystorepass}"
     * @required
     */
    protected String keystorepass;

    /**
     * The certificate alias name
     * 
     * @parameter expression="${j2me.keyalias}"
     * @required
     */
    protected String keyalias;

    /**
     * The certificate (private key) password
     * 
     * @parameter expression="${j2me.keypass}"
     * @required
     */
    protected String keypass;

    public void execute() throws MojoExecutionException, MojoFailureException {
        executeSignJar(this, classifier, false, keystore, keystorepass, keyalias, keypass);
    }

    public static void executeSignJar(AbstractJadWtkMojo mojo, String packageClassifier, boolean isTest, File keyStore,
            String storePass, String certAlias, String certPass) throws MojoExecutionException, MojoFailureException {
        if (mojo.wtkHome != null) {
            WtkSign task = signWtkJad(mojo, packageClassifier, isTest, keyStore, storePass, certAlias, certPass);
            mojo.executeTask(task);
        } else {
            throw new MojoFailureException("Signing is only available for wtk builds");
        }
    }

    protected static WtkSign signWtkJad(AbstractJadWtkMojo mojo, String packageClassifier, boolean isTest,
            File keyStore, String storePass, String certAlias, String certPass) throws MojoExecutionException,
            MojoFailureException {

        if (keyStore == null) {
            throw new MojoFailureException("<keystore> tag missing or j2me.keystore not defined");
        }

        if (storePass == null) {
            throw new MojoFailureException("<keystorepass> tag missing or j2me.keystorepass not defined");
        }

        if (certAlias == null) {
            throw new MojoFailureException("<keyalias> tag missing or j2me.keyalias not defined");
        }

        if (certPass == null) {
            throw new MojoFailureException("<keypass> tag missing or j2me.keypass not defined");
        }

        WtkSign task = new WtkSign();
        mojo.initTask(task);

        setFileValue(task, "setJarFile", mojo.getJarFile(packageClassifier));
        setFileValue(task, "setJadFile", mojo.getJadFile(packageClassifier));
        setFileValue(task, "setKeyStore", keyStore);

        task.setStorePass(storePass);
        task.setCertAlias(certAlias);
        task.setCertPass(certPass);

        return task;
    }
}
